/*
 * AllupImpl.cc
 *
 * Copyright (c) 2003, 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file AllupImpl.cc
 *
 * Implementation file for the AllupImpl class.
 */

#include "config.h"

#include <sys/types.h>
#include <signal.h>

#include <assert_pp.h>

#include "AllupImpl.hh"

#include "FactoryLibrary_ltdl.hh"

AllupImpl::AllupImpl(PortableServer::POA_ptr my_poa) :
    ai_POA(PortableServer::POA::_duplicate(my_poa))
{
}

AllupImpl::~AllupImpl(void)
{
}

edu::utah::pces::FactoryLibrary_ptr AllupImpl::OpenLibrary(const char *name)
    throw (edu::utah::pces::NoSuchLibrary,
	   CORBA::SystemException)
{
    edu::utah::pces::FactoryLibrary_var retval;

    /* Check the input and */
    if( name == NULL )
    {
	throw CORBA::BAD_PARAM();
    }

    /* Try opening the library and */
    retval = FactoryLibrary_ltdl::OpenLibrary(this->ai_POA.in(), name);

    /* ... then add it to the map, if it is not already there. */
    if( this->ai_Libraries.count(name) == 0 )
    {
	this->ai_Libraries[name] = edu::utah::pces::FactoryLibrary::
	    _duplicate(retval.in());
    }
    
    return( retval._retn() );
}

edu::utah::pces::FactoryLibraryList *AllupImpl::Libraries(void)
    throw (CORBA::SystemException)
{
    edu::utah::pces::FactoryLibraryList *retval;
    library_map_t::const_iterator pos;
    size_t list_size;
    int lpc;

    list_size = this->ai_Libraries.size();
    /* Create a sequence large enough to hold all the opened libraries and */
    retval = new edu::utah::pces::FactoryLibraryList(list_size);
    retval->length(list_size);
    /* ... fill it in. */
    for( pos = this->ai_Libraries.begin(), lpc = 0;
	 pos != this->ai_Libraries.end();
	 pos++, lpc++ )
    {
	(*retval)[lpc] = edu::utah::pces::FactoryLibrary::
	    _duplicate(pos->second.in());
    }
    return( retval );
}

void AllupImpl::Shutdown(void)
    throw (CORBA::SystemException)
{
    library_map_t::iterator pos;
    char *argv[] = { NULL };
    CORBA::ORB_var orb;
    int argc = 0;

    orb = CORBA::ORB_init(argc, argv);
    /* Try to clean up the libraries and */
    for( pos = this->ai_Libraries.begin();
	 pos != this->ai_Libraries.end();
	 pos++ )
    {
	PortableServer::ObjectId_var oid;
	PortableServer::ServantBase *sb;
	
	oid = this->ai_POA->reference_to_id(pos->second.in());
	sb = this->ai_POA->id_to_servant(oid.in());
	this->ai_POA->deactivate_object(oid.in());

	delete sb;
	sb = NULL;
    }
    FactoryLibrary_ltdl::Shutdown();
    /* ... shutdown the ORB to break the run() loop. */
    orb->shutdown(0);
}
