/*
 * FakeDelegate.hh
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file FakeDelegate.hh
 *
 * Header file for fake C++ delegates.
 */

#ifndef _fake_delegate_hh
#define _fake_delegate_hh

/**
 * Abstract class for fake C++ delegates that work with the rk_stub library.
 */
class FakeDelegate
{

public:

    /**
     * Construct an empty delegate.
     */
    FakeDelegate();

    /**
     * Deconstruct a delegate.
     */
    virtual ~FakeDelegate();

    /**
     * Pure virtual method that is called by cxx_delegate_precall.
     *
     * @return A valid rk_stub_precall_retval_t value.
     */
    virtual rk_stub_precall_retval_t precall(void) = 0;

    /**
     * Pure virtual method that is called by cxx_delegate_postcall.
     */
    virtual void postcall(void) = 0;
    
};

/**
 * Callback for rk_stub_mk_pid that will cast the parameter to a Delegate
 * object and call Delegate::precall().  Typically, this function would be
 * passed as the precall argument to rk_stub_mk_pid().
 *
 * @param obj The Delegate object.
 * @return The result of Delegate::precall().
 */
rk_stub_precall_retval_t cxx_delegate_precall(void *obj);

/**
 * Callback for rk_stub_mk_pid that will cast the parameter to a Delegate
 * object and call Delegate::postcall().  Typically, this function would be
 * passed as the postcall argument to rk_stub_mk_pid().
 *
 * @param obj The Delegate object.
 */
void cxx_delegate_postcall(void *obj);

#endif
