/*
 * StubRealTimeTask.hh
 *
 * Copyright (c) 2003, 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file StubRealTimeTask.hh
 *
 * Header file and implementation for the StubRealTimeTask class.
 */

#ifndef _stub_real_time_task_hh
#define _stub_real_time_task_hh

#include <time_util.h>

#include "BrokerS.h"

/**
 * A Broker::RealTimeTask class that can be used for testing.
 */
class StubRealTimeTask : public POA_Broker::RealTimeTask
{

public:

    /**
     * Construct an empty StubRealTimeTask object.
     */
    StubRealTimeTask(const char *name)
    {
	this->srtt_Name = name;
    };

    /**
     * Deconstruct a StubTask object.
     */
    virtual ~StubRealTimeTask()
    {
    };

    /**
     * @return The name passed in the constructor.
     */
    virtual char *Name()
	throw (CORBA::SystemException)
    {
	return( this->srtt_Name._retn() );
    };

    /** @copydoc Broker::RealTimeTask::SetManager */
    virtual void SetManager(Broker::Manager_ptr man)
	throw (CORBA::SystemException)
    {
	this->srtt_Manager = Broker::Manager::_duplicate(man);
    };
    
    /** @copydoc Broker::RealTimeTask::BeginCPUScheduling */
    virtual void BeginCPUScheduling(const Broker::ScheduleParameters &sp)
	throw (CORBA::SystemException,
	       Broker::DuplicateScheduleParameter,
	       Broker::InvalidScheduleParameter,
	       Broker::MissingScheduleParameter)
    {
    };
    
    /** @copydoc Broker::RealTimeTask::EndCPUScheduling */
    virtual void EndCPUScheduling(void)
	throw (CORBA::SystemException)
    {
    };
    
    /** @copydoc Broker::RealTimeTask::PassCPU */
    virtual Broker::CPUReserve PassCPU(Broker::RealTimeTask_ptr rtt,
				       const Broker::CPUReserve &status,
				       const Broker::CPUReserve &advice,
				       const Broker::KeyedReportParameters &krp)
	throw (CORBA::SystemException)
    {
	return this->srtt_Manager->ChangeTaskCPU(rtt, advice);
    };

    /** @copydoc Broker::RealTimeTask::ReportCPU */
    virtual Broker::CPUReserve ReportCPU(const Broker::CPUReserve &status,
					 const Broker::CPUReserve &advice,
					 const Broker::KeyedReportParameters &krp)
	throw (CORBA::SystemException)
    {
	return this->PassCPU(this->_this(), status, advice, krp);
    };

private:

    /**
     * The Broker::Manager used to handle scheduling during contention.  Only
     * valid between #BeginCPUScheduling and #EndCPUScheduling calls.
     */
    Broker::Manager_var srtt_Manager;
    
    /**
     * The task name.
     */
    CORBA::String_var srtt_Name;
    
};

#endif
