#! /bin/sh

BROKER_ALLUP="${top_builddir}/allup/src/broker_allup -ORBEndpoint iiop://localhost:0"
CBHEY=${top_builddir}/cbhey/src/cbhey

sleep 50 &
SLEEP_PID="$!"

$BROKER_ALLUP -f -p allup.pid > allup.out 2>&1

trap 'kill `cat allup.pid`; kill $SLEEP_PID' EXIT

sleep 2

##

run_test $CBHEY -l

grep_output_for "IDL:BrokerPolicies/StrictPolicy:1.0" \
    "Unable to list supported interfaces?"

##

$CBHEY file://allup.ior create library with name ${top_builddir}/libbroker/src/.libs/libcpu-broker > cb.ior
$CBHEY file://allup.ior create library with name ${top_builddir}/policies/src/.libs/libpolicies > policies.ior
$CBHEY file://cb.ior create manager with name dummy > manager.ior
$CBHEY file://policies.ior create strict-policy with name dummy > strict_policy.ior
$CBHEY file://manager.ior set policy to file://strict_policy.ior > /dev/null
$CBHEY file://cb.ior create real-time-task with name rt1 > rt1.ior

##

run_test $CBHEY file://strict_policy.ior foo

check_output "Able to use unknown verb?" <<EOF
Parse error: Unknown verb value.
EOF

##

run_test $CBHEY file://strict_policy.ior list

check_output "Unable to list root properties?" <<EOF
max-cpu
tasks
task
EOF

##

run_test $CBHEY file://strict_policy.ior list foo

check_output "Able to list unknown property?" <<EOF
Unknown property: foo
EOF

##

run_test $CBHEY file://strict_policy.ior list tasks

check_output "Unable to list tasks?" <<EOF
EOF

##

run_test $CBHEY file://strict_policy.ior list task

check_output "Unable to list properties of task?" <<EOF
priority
EOF

##

run_test $CBHEY file://strict_policy.ior get foo

check_output "Able to get unknown property?" <<EOF
Unknown property: foo
EOF

##

run_test $CBHEY file://strict_policy.ior get

check_output "Able to 'get' the root property?" <<EOF
Parse error: No more properties
EOF

##

run_test $CBHEY file://strict_policy.ior set

check_output "Able to 'set' the root property?" <<EOF
Parse error: Missing 'to' keyword.
EOF

##

run_test $CBHEY file://strict_policy.ior set max-cpu to 0.25

check_output "Unable to set max-cpu?" <<EOF
ok
EOF

##

run_test $CBHEY file://strict_policy.ior get max-cpu

check_output "max-cpu doesn't match after set?" <<EOF
0.25
EOF

##

run_test $CBHEY file://strict_policy.ior set max-cpu to 25

check_output "Able to set max-cpu to a bogus value?" <<EOF
Invalid percentage, expecting a value greater than 0.01 and less than 0.99
EOF

##

run_test $CBHEY file://strict_policy.ior set max-cpu to 0.995

check_output "Able to set max-cpu to a bogus value?" <<EOF
Invalid percentage, expecting a value greater than 0.01 and less than 0.99
EOF

##

run_test $CBHEY -- file://strict_policy.ior set max-cpu to -25

check_output "Able to set max-cpu to a bogus value?" <<EOF
Invalid percentage, expecting a value greater than 0.01 and less than 0.99
EOF

##

run_test $CBHEY file://strict_policy.ior set max-cpu to 0.005

check_output "Able to set max-cpu to a bogus value?" <<EOF
Invalid percentage, expecting a value greater than 0.01 and less than 0.99
EOF

##

run_test $CBHEY file://strict_policy.ior getsuites

check_output "Unable to get the root suites?" <<EOF
Property:  tasks
  Supported verbs: list
List tasks currently being managed.

Property:  tasks
  Supported verbs: getsuites
Get a description of the sub-properties of task.

Property:  task
  Supported verbs: get
  Specifiers:  name:string - The task name.
Get the IOR for the task matching the given name.

Property:  max-cpu
  Supported verbs: get set
Get or set the maximum CPU allocation.  The value is a floating point number
between 0.0 and 1.0 that represents the percentage of CPU that the policy
will allocate to the tasks it manages.

EOF

##

run_test $CBHEY file://strict_policy.ior getsuites of task

check_output "Unable to get the task suites?" <<EOF
Property:  priority
  Supported verbs: get set
Set or get the priority of the given task in this policy.

EOF

##

run_test $CBHEY file://manager.ior execute add-task with task file://rt1.ior period 1000000 pid $SLEEP_PID

check_output "Unable to add task?" <<EOF
ok
EOF

##

run_test $CBHEY -c IDL:Broker/RealTimeTask:1.0 file://rt1.ior execute report-cpu with status.period 100000 status.compute 5000 advice.period 100000 advice.compute 5000

check_output "Unable to execute report-cpu on python advocate?" <<EOF
ok
EOF

##
