/*
 * StubBasicTaskCallback.hh
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file StubBasicTaskCallback.hh
 *
 * Header file and implementation of the StubBasicTaskCallback class.
 */

#ifndef _stub_basic_task_callback_hh
#define _stub_basic_task_callback_hh

#include "BasicTaskCallbackS.h"

/**
 * A stub Qosket::Basic::BasicTaskCallback that can be used for testing.
 */
class StubBasicTaskCallback :
    public virtual POA_Qosket::Basic::BasicTaskCallback
{

public:

    /**
     * Construct a new StubBasicTaskCallback.
     */
    StubBasicTaskCallback(void)
    {
	this->btc_Missed = 0;
	this->btc_Made = 0;
    }

    /**
     * Deconstruct a StubBasicTaskCallback.
     */
    virtual ~StubBasicTaskCallback(void)
    {
    };

    /**
     * Log a message through the callback.  This implementation ignores the
     * parameter and prints nothing.
     *
     * @param msg The message to log.
     */
    void sendMessage(const char *msg)
	throw (CORBA::SystemException)
    {
    }

    /**
     * @copydoc Qosket::Basic::BasicTaskCallback::MissedDeadline
     *
     * This implementation will simply increment the btc_Missed variable by
     * one.
     */
    void MissedDeadline(void)
	throw (CORBA::SystemException)
    {
	this->btc_Missed += 1;
    }
    
    /**
     * @copydoc Qosket::Basic::BasicTaskCallback::MadeDeadline
     *
     * This implementation will simply increment the btc_Made variable by one.
     */
    void MadeDeadline(void)
	throw (CORBA::SystemException)
    {
	this->btc_Made += 1;
    }

    /**
     * Counter that records the number of times MissedDeadline() has been
     * called.
     */
    unsigned int btc_Missed;

    /**
     * Counter that records the number of times MadeDeadline() has been called.
     */
    unsigned int btc_Made;
    
};

#endif
