/*
 * ContractDelegate.hh
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file ContractDelegate.hh
 *
 * Header file for a delegate that extends the BasicDelegate to support QuO
 * contracts.
 */

#ifndef _contract_delegate_hh
#define _contract_delegate_hh

#include <quoC.h>

#include <BasicDelegate.hh>

/**
 * A BasicDelegate that will evaluate a QuO contract during a precall/postcall.
 *
 * XXX Make a template?
 */
class ContractDelegate : public BasicDelegate
{

public:

    /**
     * Construct a ContractDelegate with the given values.
     *
     * @param contract The contract to evaluate.
     * @param name The name value to pass to BasicDelegate's constructor.
     * @param period The period value to pass to BasicDelegate's constructor.
     * @param deadline The deadline value to pass to BasicDelegate's
     *                 constructor.
     */
    ContractDelegate(quo::Contract_ptr contract,
		     const char *name,
		     unsigned long period,
		     unsigned long deadline);

    /**
     * The premethod callback.  This implementation will evaluate the contract,
     * call the parent method, and evaluate the contract again.
     *
     * @sa BasicDelegate::precall
     */
    virtual rk_stub_precall_retval_t precall(void);
    
    /**
     * The postmethod callback.  This implementation will evaluate the
     * contract, call the parent method, and evaluate the contract again.
     *
     * @sa BasicDelegate::postcall
     */
    virtual void postcall(void);

private:

    /**
     * The contract to evaluate.
     */
    quo::Contract_var cd_Contract;
    
};

#endif
