/*
 * RKObserverAdvocate.hh
 *
 * Copyright (c) 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file RKObserverAdvocate.hh
 *
 * Header file for the RKObserverAdvocate class.
 */

#ifndef _rk_observer_advocate_hh
#define _rk_observer_advocate_hh

#include <rk.h>
#include <pthread.h>
#include <RealTimeTaskDelegateImpl.hh>

/**
 * An advocate that periodically polls an RK resource set and automatically
 * sends a report with the usage observed over the last period.
 */
class RKObserverAdvocate : public virtual RealTimeTaskDelegateImpl
{

public:

    /**
     * Construct the advocate.
     */
    RKObserverAdvocate(void)
	throw (CORBA::SystemException);

    /**
     * Deconstruct the advocate.
     */
    virtual ~RKObserverAdvocate(void);

    /** @copydoc Broker::Task::BeginCPUScheduling */
    virtual void BeginCPUScheduling(const Broker::ScheduleParameters &sp)
	throw (CORBA::SystemException,
	       Broker::DuplicateScheduleParameter,
	       Broker::InvalidScheduleParameter,
	       Broker::MissingScheduleParameter);
    
    /** @copydoc Broker::Task::EndCPUScheduling */
    virtual void EndCPUScheduling(void)
	throw (CORBA::SystemException);

    /**
     * The main polling loop.
     */
    virtual void run(void);
    
private:

    /**
     * A cached reference to this CORBA object.
     */
    Broker::RealTimeTask_var rkoa_Advocate;

    /**
     * Mutex used to serialize access to this object.
     */
    pthread_mutex_t rkoa_Mutex;

    /**
     * Condition variable used to block/unblock the polling loop.
     */
    pthread_cond_t rkoa_Cond;

    /**
     * Reference to the polling thread.
     */
    pthread_t rkoa_Thread;

    /**
     * The task's period in a convenient form.
     */
    struct timespec rkoa_Period;

    /**
     * The resource set being monitored.
     */
    volatile rk_resource_set_t rkoa_ResourceSet;

};

#endif
