/*
 * QuoAdvocate.cc
 *
 * Copyright (c) 2003, 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file QuoAdvocate.cc
 *
 * Implementation of the QuoAdvocate class.
 */

#include "config.h"

#include <string.h>
#include <sys/time.h>

#include <iostream>
#include <fstream>
#include <iomanip>

#include "QuoAdvocate.hh"

QuoAdvocate::QuoAdvocate(void)
{
}

QuoAdvocate::~QuoAdvocate()
{
}

void QuoAdvocate::SetDelegateAttributeObject(const char *name,
					     const CORBA::Object_ptr value)
    throw (CORBA::SystemException)
{
    if( name == NULL )
    {
	throw CORBA::BAD_PARAM();
    }
    else if( (strcasecmp(name, "status-sc") == 0) ||
	     (strcasecmp(name, "status_sc") == 0) ||
	     (strcasecmp(name, "status sc") == 0) )
    {
	this->eta_Status = quo::ValueSC::
	    _duplicate(quo::ValueSC::_narrow(value));
    }
    else if( (strcasecmp(name, "advice-sc") == 0) ||
	     (strcasecmp(name, "advice_sc") == 0) ||
	     (strcasecmp(name, "advice sc") == 0) )
    {
	this->eta_Advice = quo::ValueSC::
	    _duplicate(quo::ValueSC::_narrow(value));
    }
    else
    {
	this->RealTimeTaskDelegateImpl::SetDelegateAttributeObject(name,
								   value);
    }
}

CORBA::Any_ptr QuoAdvocate::GetDelegateAttribute(const char *name)
    throw (CORBA::SystemException)
{
    CORBA::Any_var retval;
    
    if( name == NULL )
    {
	throw CORBA::BAD_PARAM();
    }
    else if( (strcasecmp(name, "status-sc") == 0) ||
	     (strcasecmp(name, "status_sc") == 0) ||
	     (strcasecmp(name, "status sc") == 0) )
    {
	retval = new CORBA::Any();
	(*retval) <<= this->eta_Status.in();
    }
    else if( (strcasecmp(name, "advice-sc") == 0) ||
	     (strcasecmp(name, "advice_sc") == 0) ||
	     (strcasecmp(name, "advice sc") == 0) )
    {
	retval = new CORBA::Any();
	(*retval) <<= this->eta_Advice.in();
    }
    else
    {
	retval = this->RealTimeTaskDelegateImpl::GetDelegateAttribute(name);
    }
    return( retval._retn() );
}

Broker::CPUReserve QuoAdvocate::PassCPU(Broker::RealTimeTask_ptr rtt,
					const Broker::CPUReserve &status,
					const Broker::CPUReserve &advice,
					const Broker::KeyedReportParameters &krp)
    throw (CORBA::SystemException)
{
    if( CORBA::is_nil(this->dm_RemoteObject.in()) )
    {
	throw CORBA::BAD_INV_ORDER();
    }
    
    if( !CORBA::is_nil(this->eta_Status.in()) )
    {
	this->eta_Status->longValue(status.Compute);
    }
    if( !CORBA::is_nil(this->eta_Advice.in()) )
    {
	this->eta_Advice->longValue(advice.Compute);
    }
    return this->RealTimeTaskDelegateImpl::PassCPU(rtt, status, advice, krp);
}
